"""
Generated class for PaymentReconciliation. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Money import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Allocation(FhirBaseModel):
    """Distribution of the payment amount for a previously acknowledged payable.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Business identifier of the payment detail
    :param Identifier predecessor: Business identifier of the prior payment detail
    :param Reference target: Subject of the payment
    :param str targetItemString: Sub-element of the subject
    :param Identifier targetItemIdentifier: Sub-element of the subject
    :param int targetItemPositiveInt: Sub-element of the subject
    :param Reference encounter: Applied-to encounter
    :param Reference account: Applied-to account
    :param CodeableConcept type: Category of payment
    :param Reference submitter: Submitter of the request
    :param Reference response: Response committing to a payment
    :param str date: Date of commitment to pay
    :param Reference responsible: Contact for the response
    :param Reference payee: Recipient of the payment
    :param Money amount: Amount allocated to this payable
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "predecessor": {"class_name": "Identifier", "is_contained": False},
        "target": {"class_name": "Reference", "is_contained": False},
        "targetItemIdentifier": {"class_name": "Identifier", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "account": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "submitter": {"class_name": "Reference", "is_contained": False},
        "response": {"class_name": "Reference", "is_contained": False},
        "responsible": {"class_name": "Reference", "is_contained": False},
        "payee": {"class_name": "Reference", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        predecessor: "Identifier" = None,
        target: "Reference" = None,
        targetItemString: "str" = None,
        targetItemIdentifier: "Identifier" = None,
        targetItemPositiveInt: "int" = None,
        encounter: "Reference" = None,
        account: "Reference" = None,
        type: "CodeableConcept" = None,
        submitter: "Reference" = None,
        response: "Reference" = None,
        date: "str" = None,
        responsible: "Reference" = None,
        payee: "Reference" = None,
        amount: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.predecessor = predecessor
        self.target = target
        self.targetItemString = targetItemString
        self.targetItemIdentifier = targetItemIdentifier
        self.targetItemPositiveInt = targetItemPositiveInt
        self.encounter = encounter
        self.account = account
        self.type = type
        self.submitter = submitter
        self.response = response
        self.date = date
        self.responsible = responsible
        self.payee = payee
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "PaymentReconciliation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PaymentReconciliation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProcessNote(FhirBaseModel):
    """A note that describes or explains the processing in a human readable form.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: display | print | printoper
    :param str text: Note explanatory text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        text: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "PaymentReconciliation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PaymentReconciliation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PaymentReconciliation(DomainResource):
    """This resource provides the details including amount of a payment and allocates the payment items being paid.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for a payment reconciliation
    :param CodeableConcept type: Category of payment
    :param str status: active | cancelled | draft | entered-in-error
    :param CodeableConcept kind: Workflow originating payment
    :param Period period: Period covered
    :param str created: Creation date
    :param Reference enterer: Who entered the payment
    :param CodeableConcept issuerType: Nature of the source
    :param Reference paymentIssuer: Party generating payment
    :param Reference request: Reference to requesting resource
    :param Reference requestor: Responsible practitioner
    :param str outcome: queued | complete | error | partial
    :param str disposition: Disposition message
    :param str date: When payment issued
    :param Reference location: Where payment collected
    :param CodeableConcept method: Payment instrument
    :param str cardBrand: Type of card
    :param str accountNumber: Digits for verification
    :param str expirationDate: Expiration year-month
    :param str processor: Processor name
    :param str referenceNumber: Check number or payment reference
    :param str authorization: Authorization number
    :param Money tenderedAmount: Amount offered by the issuer
    :param Money returnedAmount: Amount returned by the receiver
    :param Money amount: Total amount of Payment
    :param Identifier paymentIdentifier: Business identifier for the payment
    :param Allocation allocation: Settlement particulars
    :param CodeableConcept formCode: Printed form identifier
    :param ProcessNote processNote: Note concerning processing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "kind": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "enterer": {"class_name": "Reference", "is_contained": False},
        "issuerType": {"class_name": "CodeableConcept", "is_contained": False},
        "paymentIssuer": {"class_name": "Reference", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "requestor": {"class_name": "Reference", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "tenderedAmount": {"class_name": "Money", "is_contained": False},
        "returnedAmount": {"class_name": "Money", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
        "paymentIdentifier": {"class_name": "Identifier", "is_contained": False},
        "allocation": {"class_name": "Allocation", "is_contained": True},
        "formCode": {"class_name": "CodeableConcept", "is_contained": False},
        "processNote": {"class_name": "ProcessNote", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "CodeableConcept" = None,
        status: "str" = None,
        kind: "CodeableConcept" = None,
        period: "Period" = None,
        created: "str" = None,
        enterer: "Reference" = None,
        issuerType: "CodeableConcept" = None,
        paymentIssuer: "Reference" = None,
        request: "Reference" = None,
        requestor: "Reference" = None,
        outcome: "str" = None,
        disposition: "str" = None,
        date: "str" = None,
        location: "Reference" = None,
        method: "CodeableConcept" = None,
        cardBrand: "str" = None,
        accountNumber: "str" = None,
        expirationDate: "str" = None,
        processor: "str" = None,
        referenceNumber: "str" = None,
        authorization: "str" = None,
        tenderedAmount: "Money" = None,
        returnedAmount: "Money" = None,
        amount: "Money" = None,
        paymentIdentifier: "Identifier" = None,
        allocation: list["Allocation"] = None,
        formCode: "CodeableConcept" = None,
        processNote: list["ProcessNote"] = None,
    ):

        self.resourceType = "PaymentReconciliation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.status = status
        self.kind = kind
        self.period = period
        self.created = created
        self.enterer = enterer
        self.issuerType = issuerType
        self.paymentIssuer = paymentIssuer
        self.request = request
        self.requestor = requestor
        self.outcome = outcome
        self.disposition = disposition
        self.date = date
        self.location = location
        self.method = method
        self.cardBrand = cardBrand
        self.accountNumber = accountNumber
        self.expirationDate = expirationDate
        self.processor = processor
        self.referenceNumber = referenceNumber
        self.authorization = authorization
        self.tenderedAmount = tenderedAmount
        self.returnedAmount = returnedAmount
        self.amount = amount
        self.paymentIdentifier = paymentIdentifier
        self.allocation = allocation or []
        self.formCode = formCode
        self.processNote = processNote or []

    @classmethod
    def from_dict(cls, data: dict) -> "PaymentReconciliation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "PaymentReconciliation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Event. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Element import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Timing import *


class Performer(FhirBaseModel):
    """Indicates who or what performed the {{title}} and how they were involved.:param CodeableConcept function: Type of performance
    :param Reference actor: Who performed {{title}}
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "Event":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Event":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Event(FhirBaseModel):
    """Logical Model: A pattern to be followed by resources that represent the performance of some activity, possibly in accordance with a request or service definition.
    :param Identifier identifier: Business identifier for {{title}}
    :param Reference basedOn: Fulfills plan, proposal or order
    :param Reference partOf: Part of referenced event
    :param Reference researchStudy: Associated research study
    :param str status: preparation | in-progress | not-done | suspended | aborted | completed | entered-in-error | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param CodeableConcept category: High level categorization of {{title}}
    :param CodeableConcept code: What service was done
    :param CodeableReference product: Product used/provided
    :param Reference subject: Individual service was done for/to
    :param Reference encounter: Encounter the {{title}} is part of
    :param str occurrenceDateTime: When {{title}} occurred/is occurring
    :param Period occurrencePeriod: When {{title}} occurred/is occurring
    :param Timing occurrenceTiming: When {{title}} occurred/is occurring
    :param str recorded: When {{title}} was first captured in the subject's record
    :param bool reportedBoolean: Reported rather than primary record
    :param Reference reportedReference: Reported rather than primary record
    :param Performer performer: Who performed {{title}} and what they did
    :param Reference location: Where {{title}} occurred
    :param CodeableReference reason: Why was {{title}} performed?
    :param Annotation note: Comments made about the event
    :param Reference relevantHistory: Key events in history of {{title}}
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "researchStudy": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "product": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "reportedReference": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "location": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        researchStudy: list["Reference"] = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        product: "CodeableReference" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        recorded: "str" = None,
        reportedBoolean: "bool" = None,
        reportedReference: "Reference" = None,
        performer: list["Performer"] = None,
        location: "Reference" = None,
        reason: list["CodeableReference"] = None,
        note: list["Annotation"] = None,
        relevantHistory: list["Reference"] = None,
    ):

        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.researchStudy = researchStudy or []
        self.status = status
        self.statusReason = statusReason
        self.category = category or []
        self.code = code
        self.product = product
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.recorded = recorded
        self.reportedBoolean = reportedBoolean
        self.reportedReference = reportedReference
        self.performer = performer or []
        self.location = location
        self.reason = reason or []
        self.note = note or []
        self.relevantHistory = relevantHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "Event":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Event":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Participant. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Identifier import *


class Participant(FhirBaseModel):
    """Logical Model: A pattern followed by resources that represent the participant in some activity, process, or responsible for providing information about a resource.
    :param Identifier identifier: Business Identifier for {{title}}
    :param bool active: Whether the {{title}} is currently active
    :param str name: A name for the {{title}}
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        name: "str" = None,
    ):

        self.identifier = identifier or []
        self.active = active
        self.name = name

    @classmethod
    def from_dict(cls, data: dict) -> "Participant":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Participant":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Base. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel


class Base(FhirBaseModel):
    """Base Type: Base definition for all types defined in FHIR type system."""

    # needed for complex properties where the element name is different from the class name
    property_class_info = {}

    def __init__(
        self,
    ):

        self.resourceType = "Base"

    @classmethod
    def from_dict(cls, data: dict) -> "Base":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Base":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DocumentReference. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class RelatesTo(FhirBaseModel):
    """Relationships that this document has with other document references that already exist.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: replaces | transforms | signs | appends
    :param Reference target: Target of the relationship
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "target": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        target: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.target = target

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Content(FhirBaseModel):
    """The document and format referenced. There may be multiple content element repetitions, each with a different format.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Attachment attachment: Where to access the document
    :param Coding format: Format/content rules for the document
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "attachment": {"class_name": "Attachment", "is_contained": False},
        "format": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        attachment: "Attachment" = None,
        format: "Coding" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.attachment = attachment
        self.format = format

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Context(FhirBaseModel):
    """The clinical context in which the document was prepared.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference encounter: Context of the document  content
    :param CodeableConcept event: Main clinical acts documented
    :param Period period: Time of service that is being documented
    :param CodeableConcept facilityType: Kind of facility where patient was seen
    :param CodeableConcept practiceSetting: Additional details about where the content was created (e.g. clinical specialty)
    :param Reference sourcePatientInfo: Patient demographics from source
    :param Reference related: Related identifiers or resources
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "event": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "facilityType": {"class_name": "CodeableConcept", "is_contained": False},
        "practiceSetting": {"class_name": "CodeableConcept", "is_contained": False},
        "sourcePatientInfo": {"class_name": "Reference", "is_contained": False},
        "related": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        encounter: list["Reference"] = None,
        event: list["CodeableConcept"] = None,
        period: "Period" = None,
        facilityType: "CodeableConcept" = None,
        practiceSetting: "CodeableConcept" = None,
        sourcePatientInfo: "Reference" = None,
        related: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.encounter = encounter or []
        self.event = event or []
        self.period = period
        self.facilityType = facilityType
        self.practiceSetting = practiceSetting
        self.sourcePatientInfo = sourcePatientInfo
        self.related = related or []

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DocumentReference(DomainResource):
    """A reference to a document of any kind for any purpose. Provides metadata about the document so that the document can be discovered and managed. The scope of a document is any seralized object with a mime-type, so includes formal patient centric documents (CDA), cliical notes, scanned paper, and non-patient specific documents like policy text.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier masterIdentifier: Master Version Specific Identifier
    :param Identifier identifier: Other identifiers for the document
    :param str status: current | superseded | entered-in-error
    :param str docStatus: preliminary | final | amended | entered-in-error
    :param CodeableConcept type: Kind of document (LOINC if possible)
    :param CodeableConcept category: Categorization of document
    :param Reference subject: Who/what is the subject of the document
    :param str date: When this document reference was created
    :param Reference author: Who and/or what authored the document
    :param Reference authenticator: Who/what authenticated the document
    :param Reference custodian: Organization which maintains the document
    :param RelatesTo relatesTo: Relationships to other documents
    :param str description: Human-readable description
    :param CodeableConcept securityLabel: Document security-tags
    :param Content content: Document referenced
    :param Context context: Clinical context of document
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "masterIdentifier": {"class_name": "Identifier", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "authenticator": {"class_name": "Reference", "is_contained": False},
        "custodian": {"class_name": "Reference", "is_contained": False},
        "relatesTo": {"class_name": "RelatesTo", "is_contained": True},
        "securityLabel": {"class_name": "CodeableConcept", "is_contained": False},
        "content": {"class_name": "Content", "is_contained": True},
        "context": {"class_name": "Context", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        masterIdentifier: "Identifier" = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        docStatus: "str" = None,
        type: "CodeableConcept" = None,
        category: list["CodeableConcept"] = None,
        subject: "Reference" = None,
        date: "str" = None,
        author: list["Reference"] = None,
        authenticator: "Reference" = None,
        custodian: "Reference" = None,
        relatesTo: list["RelatesTo"] = None,
        description: "str" = None,
        securityLabel: list["CodeableConcept"] = None,
        content: list["Content"] = None,
        context: "Context" = None,
    ):

        self.resourceType = "DocumentReference"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.masterIdentifier = masterIdentifier
        self.identifier = identifier or []
        self.status = status
        self.docStatus = docStatus
        self.type = type
        self.category = category or []
        self.subject = subject
        self.date = date
        self.author = author or []
        self.authenticator = authenticator
        self.custodian = custodian
        self.relatesTo = relatesTo or []
        self.description = description
        self.securityLabel = securityLabel or []
        self.content = content or []
        self.context = context

    @classmethod
    def from_dict(cls, data: dict) -> "DocumentReference":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DocumentReference":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for OperationDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Binding(FhirBaseModel):
    """Binds to a value set if this parameter is coded (code, Coding, CodeableConcept).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str strength: required | extensible | preferred | example
    :param str valueSet: Source of value set
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        strength: "str" = None,
        valueSet: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.strength = strength
        self.valueSet = valueSet

    @classmethod
    def from_dict(cls, data: dict) -> "OperationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ReferencedFrom(FhirBaseModel):
    """Identifies other resource parameters within the operation invocation that are expected to resolve to this resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str source: Referencing parameter
    :param str sourceId: Element id of reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        source: "str" = None,
        sourceId: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.source = source
        self.sourceId = sourceId

    @classmethod
    def from_dict(cls, data: dict) -> "OperationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Parameter(FhirBaseModel):
    """The parameters for the operation/query.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name in Parameters.parameter.name or in URL
    :param str use: in | out
    :param int min: Minimum Cardinality
    :param str max: Maximum Cardinality (a number or *)
    :param str documentation: Description of meaning/use
    :param str type: What type this parameter has
    :param str targetProfile: If type is Reference | canonical, allowed targets
    :param str searchType: number | date | string | token | reference | composite | quantity | uri | special
    :param Binding binding: ValueSet details if this is coded
    :param ReferencedFrom referencedFrom: References to this parameter
    :param Part part: Parts of a nested Parameter
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "binding": {"class_name": "Binding", "is_contained": True},
        "referencedFrom": {"class_name": "ReferencedFrom", "is_contained": True},
        "part": {"class_name": "Part", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        use: "str" = None,
        min: "int" = None,
        max: "str" = None,
        documentation: "str" = None,
        type: "str" = None,
        targetProfile: list["str"] = None,
        searchType: "str" = None,
        binding: "Binding" = None,
        referencedFrom: list["ReferencedFrom"] = None,
        part: list["Part"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.use = use
        self.min = min
        self.max = max
        self.documentation = documentation
        self.type = type
        self.targetProfile = targetProfile or []
        self.searchType = searchType
        self.binding = binding
        self.referencedFrom = referencedFrom or []
        self.part = part or []

    @classmethod
    def from_dict(cls, data: dict) -> "OperationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Overload(FhirBaseModel):
    """Defines an appropriate combination of parameters to use when invoking this operation, to help code generators when generating overloaded parameter sets for this operation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str parameterName: Name of parameter to include in overload
    :param str comment: Comments to go on overload
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        parameterName: list["str"] = None,
        comment: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.parameterName = parameterName or []
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "OperationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class OperationDefinition(DomainResource):
    """A formal computable definition of an operation (on the RESTful interface) or a named query (using the search interaction).
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this operation definition, represented as a URI (globally unique)
    :param str version: Business version of the operation definition
    :param str name: Name for this operation definition (computer friendly)
    :param str title: Name for this operation definition (human friendly)
    :param str status: draft | active | retired | unknown
    :param str kind: operation | query
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the operation definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for operation definition (if applicable)
    :param str purpose: Why this operation definition is defined
    :param bool affectsState: Whether content is changed by the operation
    :param str code: Name used to invoke the operation
    :param str comment: Additional information about use
    :param str base: Marks this as a profile of the base
    :param str resource: Types this operation applies to
    :param bool system: Invoke at the system level?
    :param bool type: Invoke at the type level?
    :param bool instance: Invoke on an instance?
    :param str inputProfile: Validation information for in parameters
    :param str outputProfile: Validation information for out parameters
    :param Parameter parameter: Parameters for the operation/query
    :param Overload overload: Define overloaded variants for when  generating code
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "parameter": {"class_name": "Parameter", "is_contained": True},
        "overload": {"class_name": "Overload", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        kind: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        affectsState: "bool" = None,
        code: "str" = None,
        comment: "str" = None,
        base: "str" = None,
        resource: list["str"] = None,
        system: "bool" = None,
        type: "bool" = None,
        instance: "bool" = None,
        inputProfile: "str" = None,
        outputProfile: "str" = None,
        parameter: list["Parameter"] = None,
        overload: list["Overload"] = None,
    ):

        self.resourceType = "OperationDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.kind = kind
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.affectsState = affectsState
        self.code = code
        self.comment = comment
        self.base = base
        self.resource = resource or []
        self.system = system
        self.type = type
        self.instance = instance
        self.inputProfile = inputProfile
        self.outputProfile = outputProfile
        self.parameter = parameter or []
        self.overload = overload or []

    @classmethod
    def from_dict(cls, data: dict) -> "OperationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "OperationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Device. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.ContactPoint import *
from fhirmodels.R5.Count import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class UdiCarrier(FhirBaseModel):
    """Unique device identifier (UDI) assigned to device label or package.  Note that the Device may include multiple udiCarriers as it either may include just the udiCarrier for the jurisdiction it is sold, or for multiple jurisdictions it could have been sold.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str deviceIdentifier: Mandatory fixed portion of UDI
    :param str issuer: UDI Issuing Organization
    :param str jurisdiction: Regional UDI authority
    :param str carrierAIDC: UDI Machine Readable Barcode String
    :param str carrierHRF: UDI Human Readable Barcode String
    :param str entryType: barcode | rfid | manual | card | self-reported | electronic-transmission | unknown
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        deviceIdentifier: "str" = None,
        issuer: "str" = None,
        jurisdiction: "str" = None,
        carrierAIDC: "str" = None,
        carrierHRF: "str" = None,
        entryType: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.deviceIdentifier = deviceIdentifier
        self.issuer = issuer
        self.jurisdiction = jurisdiction
        self.carrierAIDC = carrierAIDC
        self.carrierHRF = carrierHRF
        self.entryType = entryType

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Name(FhirBaseModel):
    """This represents the manufacturer's name of the device as provided by the device, from a UDI label, or by a person describing the Device.  This typically would be used when a person provides the name(s) or when the device represents one of the names available from DeviceDefinition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str value: The term that names the device
    :param str type: registered-name | user-friendly-name | patient-reported-name
    :param bool display: The preferred device name
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        value: "str" = None,
        type: "str" = None,
        display: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.value = value
        self.type = type
        self.display = display

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Version(FhirBaseModel):
    """The actual design of the device or software version running on the device.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of the device version, e.g. manufacturer, approved, internal
    :param Identifier component: The hardware or software module of the device to which the version applies
    :param str installDate: The date the version was installed on the device
    :param str value: The version text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "component": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        component: "Identifier" = None,
        installDate: "str" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.component = component
        self.installDate = installDate
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ConformsTo(FhirBaseModel):
    """Identifies the standards, specifications, or formal guidances for the capabilities supported by the device. The device may be certified as conformant to these specifications e.g., communication, performance, process, measurement, or specialization standards.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Describes the common type of the standard, specification, or formal guidance.  communication | performance | measurement
    :param CodeableConcept specification: Identifies the standard, specification, or formal guidance that the device adheres to
    :param str version: Specific form or variant of the standard
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "specification": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        specification: "CodeableConcept" = None,
        version: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.specification = specification
        self.version = version

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Property(FhirBaseModel):
    """Static or essentially fixed characteristics or features of the device (e.g., time or timing attributes, resolution, accuracy, intended use or instructions for use, and physical attributes) that are not otherwise captured in more specific attributes.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Code that specifies the property being represented
    :param Quantity valueQuantity: Value of the property
    :param CodeableConcept valueCodeableConcept: Value of the property
    :param str valueString: Value of the property
    :param bool valueBoolean: Value of the property
    :param int valueInteger: Value of the property
    :param Range valueRange: Value of the property
    :param Attachment valueAttachment: Value of the property
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueBoolean: "bool" = None,
        valueInteger: "int" = None,
        valueRange: "Range" = None,
        valueAttachment: "Attachment" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueQuantity = valueQuantity
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueBoolean = valueBoolean
        self.valueInteger = valueInteger
        self.valueRange = valueRange
        self.valueAttachment = valueAttachment

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Device(DomainResource):
    """This resource describes the properties (regulated, has real time clock, etc.), adminstrative (manufacturer name, model number, serial number, firmware, etc.), and type (knee replacement, blood pressure cuff, MRI, etc.) of a physical unit (these values do not change much within a given module, for example the serail number, manufacturer name, and model number). An actual unit may consist of several modules in a distinct hierarchy and these are represented by multiple Device resources and bound through the 'parent' element.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Instance identifier
    :param str displayName: The name used to display by default when the device is referenced
    :param CodeableReference definition: The reference to the definition for the device
    :param UdiCarrier udiCarrier: Unique Device Identifier (UDI) Barcode string
    :param str status: active | inactive | entered-in-error
    :param CodeableConcept availabilityStatus: lost | damaged | destroyed | available
    :param Identifier biologicalSourceEvent: An identifier that supports traceability to the event during which material in this product from one or more biological entities was obtained or pooled
    :param str manufacturer: Name of device manufacturer
    :param str manufactureDate: Date when the device was made
    :param str expirationDate: Date and time of expiry of this device (if applicable)
    :param str lotNumber: Lot number of manufacture
    :param str serialNumber: Serial number assigned by the manufacturer
    :param Name name: The name or names of the device as known to the manufacturer and/or patient
    :param str modelNumber: The manufacturer's model number for the device
    :param str partNumber: The part number or catalog number of the device
    :param CodeableConcept category: Indicates a high-level grouping of the device
    :param CodeableConcept type: The kind or type of device
    :param Version version: The actual design of the device or software version running on the device
    :param ConformsTo conformsTo: Identifies the standards, specifications, or formal guidances for the capabilities supported by the device
    :param Property property: Inherent, essentially fixed, characteristics of the device.  e.g., time properties, size, material, etc.
    :param CodeableConcept mode: The designated condition for performing a task
    :param Count cycle: The series of occurrences that repeats during the operation of the device
    :param Duration duration: A measurement of time during the device's operation (e.g., days, hours, mins, etc.)
    :param Reference owner: Organization responsible for device
    :param ContactPoint contact: Details for human/organization for support
    :param Reference location: Where the device is found
    :param str url: Network address to contact device
    :param Reference endpoint: Technical endpoints providing access to electronic services provided by the device
    :param CodeableReference gateway: Linked device acting as a communication/data collector, translator or controller
    :param Annotation note: Device notes and comments
    :param CodeableConcept safety: Safety Characteristics of Device
    :param Reference parent: The higher level or encompassing device that this device is a logical part of
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "definition": {"class_name": "CodeableReference", "is_contained": False},
        "udiCarrier": {"class_name": "UdiCarrier", "is_contained": True},
        "availabilityStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "biologicalSourceEvent": {"class_name": "Identifier", "is_contained": False},
        "name": {"class_name": "Name", "is_contained": True},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "version": {"class_name": "Version", "is_contained": True},
        "conformsTo": {"class_name": "ConformsTo", "is_contained": True},
        "property": {"class_name": "Property", "is_contained": True},
        "mode": {"class_name": "CodeableConcept", "is_contained": False},
        "cycle": {"class_name": "Count", "is_contained": False},
        "duration": {"class_name": "Duration", "is_contained": False},
        "owner": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactPoint", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
        "gateway": {"class_name": "CodeableReference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "safety": {"class_name": "CodeableConcept", "is_contained": False},
        "parent": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        displayName: "str" = None,
        definition: "CodeableReference" = None,
        udiCarrier: list["UdiCarrier"] = None,
        status: "str" = None,
        availabilityStatus: "CodeableConcept" = None,
        biologicalSourceEvent: "Identifier" = None,
        manufacturer: "str" = None,
        manufactureDate: "str" = None,
        expirationDate: "str" = None,
        lotNumber: "str" = None,
        serialNumber: "str" = None,
        name: list["Name"] = None,
        modelNumber: "str" = None,
        partNumber: "str" = None,
        category: list["CodeableConcept"] = None,
        type: list["CodeableConcept"] = None,
        version: list["Version"] = None,
        conformsTo: list["ConformsTo"] = None,
        property: list["Property"] = None,
        mode: "CodeableConcept" = None,
        cycle: "Count" = None,
        duration: "Duration" = None,
        owner: "Reference" = None,
        contact: list["ContactPoint"] = None,
        location: "Reference" = None,
        url: "str" = None,
        endpoint: list["Reference"] = None,
        gateway: list["CodeableReference"] = None,
        note: list["Annotation"] = None,
        safety: list["CodeableConcept"] = None,
        parent: "Reference" = None,
    ):

        self.resourceType = "Device"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.displayName = displayName
        self.definition = definition
        self.udiCarrier = udiCarrier or []
        self.status = status
        self.availabilityStatus = availabilityStatus
        self.biologicalSourceEvent = biologicalSourceEvent
        self.manufacturer = manufacturer
        self.manufactureDate = manufactureDate
        self.expirationDate = expirationDate
        self.lotNumber = lotNumber
        self.serialNumber = serialNumber
        self.name = name or []
        self.modelNumber = modelNumber
        self.partNumber = partNumber
        self.category = category or []
        self.type = type or []
        self.version = version or []
        self.conformsTo = conformsTo or []
        self.property = property or []
        self.mode = mode
        self.cycle = cycle
        self.duration = duration
        self.owner = owner
        self.contact = contact or []
        self.location = location
        self.url = url
        self.endpoint = endpoint or []
        self.gateway = gateway or []
        self.note = note or []
        self.safety = safety or []
        self.parent = parent

    @classmethod
    def from_dict(cls, data: dict) -> "Device":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Device":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Request. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Annotation import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Timing import *


class Request(FhirBaseModel):
    """Logical Model: A pattern to be followed by resources that represent a specific proposal, plan and/or order for some sort of action or service.
    :param Identifier identifier: Business Identifier for {{title}}
    :param Reference basedOn: Fulfills plan, proposal or order
    :param Reference replaces: Request(s) replaced by this {{title}}
    :param Identifier groupIdentifier: Composite request this is part of
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param str intent: proposal | plan | order (immutable)
    :param str priority: routine | urgent | asap | stat
    :param bool doNotPerform: true if request is prohibiting action
    :param CodeableConcept category: Partitions the {{title}} into one or more categories that can be used to filter searching, to govern access control and/or to guide system behavior.
    :param CodeableConcept code: Service requested/ordered
    :param CodeableReference product: Product requested/ordered
    :param Reference subject: Individual the service is ordered/prohibited for
    :param Reference encounter: Encounter the {{title}} is tied to
    :param str occurrenceDateTime: When service should (not) occur
    :param Period occurrencePeriod: When service should (not) occur
    :param Timing occurrenceTiming: When service should (not) occur
    :param str authoredOn: When request was created/transitioned to active
    :param Reference requester: Who/what is requesting service
    :param bool reportedBoolean: Reported rather than primary record
    :param Reference reportedReference: Reported rather than primary record
    :param CodeableConcept performerType: Desired kind of service performer
    :param Reference performer: Specific desired (non)performer
    :param Reference deliverTo: Who should receive result of {{title}}
    :param CodeableReference reason: Why is service (not) needed?
    :param Reference insurance: Associated insurance coverage
    :param Reference supportingInfo: Extra information to use in performing request
    :param Annotation note: Comments made about {{title}}
    :param Reference relevantHistory: Key events in history of {{title}}
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "replaces": {"class_name": "Reference", "is_contained": False},
        "groupIdentifier": {"class_name": "Identifier", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "product": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "reportedReference": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "deliverTo": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        replaces: list["Reference"] = None,
        groupIdentifier: "Identifier" = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        intent: "str" = None,
        priority: "str" = None,
        doNotPerform: "bool" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        product: "CodeableReference" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        authoredOn: "str" = None,
        requester: "Reference" = None,
        reportedBoolean: "bool" = None,
        reportedReference: "Reference" = None,
        performerType: "CodeableConcept" = None,
        performer: "Reference" = None,
        deliverTo: list["Reference"] = None,
        reason: list["CodeableReference"] = None,
        insurance: list["Reference"] = None,
        supportingInfo: list["Reference"] = None,
        note: list["Annotation"] = None,
        relevantHistory: list["Reference"] = None,
    ):

        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.replaces = replaces or []
        self.groupIdentifier = groupIdentifier
        self.status = status
        self.statusReason = statusReason
        self.intent = intent
        self.priority = priority
        self.doNotPerform = doNotPerform
        self.category = category or []
        self.code = code
        self.product = product
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.authoredOn = authoredOn
        self.requester = requester
        self.reportedBoolean = reportedBoolean
        self.reportedReference = reportedReference
        self.performerType = performerType
        self.performer = performer
        self.deliverTo = deliverTo or []
        self.reason = reason or []
        self.insurance = insurance or []
        self.supportingInfo = supportingInfo or []
        self.note = note or []
        self.relevantHistory = relevantHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "Request":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Request":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for CapabilityStatement. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Software(FhirBaseModel):
    """Software that is covered by this capability statement.  It is used when the capability statement describes the capabilities of a particular software version, independent of an installation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: A name the software is known by
    :param str version: Version covered by this statement
    :param str releaseDate: Date this version was released
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        version: "str" = None,
        releaseDate: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.version = version
        self.releaseDate = releaseDate

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Implementation(FhirBaseModel):
    """Identifies a specific implementation instance that is described by the capability statement - i.e. a particular installation, rather than the capabilities of a software program.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Describes this specific instance
    :param str url: Base URL for the installation
    :param Reference custodian: Organization that manages the data
    :param str implementationGuide: Implementation guides supported
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "custodian": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        url: "str" = None,
        custodian: "Reference" = None,
        implementationGuide: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.url = url
        self.custodian = custodian
        self.implementationGuide = implementationGuide or []

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Security(FhirBaseModel):
    """Information about security implementation from an interface perspective - what a client needs to know.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool cors: Adds CORS Headers (http://enable-cors.org/)
    :param CodeableConcept service: OAuth | SMART-on-FHIR | NTLM | Basic | Kerberos | Certificates
    :param str description: General description of how security works
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "service": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        cors: "bool" = None,
        service: list["CodeableConcept"] = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.cors = cors
        self.service = service or []
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Interaction(FhirBaseModel):
    """Identifies a restful operation supported by the solution.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: read | vread | update | patch | delete | history-instance | history-type | create | search-type
    :param str documentation: Anything special about operation behavior
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SearchParam(FhirBaseModel):
    """Search parameters for implementations to support and/or make use of - either references to ones defined in the specification, or additional ones defined for/by the implementation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name for parameter in search url
    :param str definition: Source of definition for parameter
    :param str type: number | date | string | token | reference | composite | quantity | uri | special
    :param str documentation: Server-specific usage
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        definition: "str" = None,
        type: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.definition = definition
        self.type = type
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Operation(FhirBaseModel):
    """Definition of an operation or a named query together with its parameters and their meaning and type. Consult the definition of the operation for details about how to invoke the operation, and the parameters.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name by which the operation/query is invoked
    :param str definition: The defined operation/query
    :param str documentation: Specific details about operation behavior
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        definition: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.definition = definition
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Resource(FhirBaseModel):
    """A specification of the restful capabilities of the solution for a specific resource type.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: A resource type that is supported
    :param str profile: System-wide profile
    :param str supportedProfile: Use-case specific profiles
    :param str documentation: Additional information about the use of the resource type
    :param Interaction interaction: What operations are supported?
    :param str versioning: no-version | versioned | versioned-update
    :param bool readHistory: Whether vRead can return past versions
    :param bool updateCreate: If update can commit to a new identity
    :param bool conditionalCreate: If allows/uses conditional create
    :param str conditionalRead: not-supported | modified-since | not-match | full-support
    :param bool conditionalUpdate: If allows/uses conditional update
    :param bool conditionalPatch: If allows/uses conditional patch
    :param str conditionalDelete: not-supported | single | multiple - how conditional delete is supported
    :param str referencePolicy: literal | logical | resolves | enforced | local
    :param str searchInclude: _include values supported by the server
    :param str searchRevInclude: _revinclude values supported by the server
    :param SearchParam searchParam: Search parameters supported by implementation
    :param Operation operation: Definition of a resource operation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "interaction": {"class_name": "Interaction", "is_contained": True},
        "searchParam": {"class_name": "SearchParam", "is_contained": True},
        "operation": {"class_name": "Operation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        profile: "str" = None,
        supportedProfile: list["str"] = None,
        documentation: "str" = None,
        interaction: list["Interaction"] = None,
        versioning: "str" = None,
        readHistory: "bool" = None,
        updateCreate: "bool" = None,
        conditionalCreate: "bool" = None,
        conditionalRead: "str" = None,
        conditionalUpdate: "bool" = None,
        conditionalPatch: "bool" = None,
        conditionalDelete: "str" = None,
        referencePolicy: list["str"] = None,
        searchInclude: list["str"] = None,
        searchRevInclude: list["str"] = None,
        searchParam: list["SearchParam"] = None,
        operation: list["Operation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.profile = profile
        self.supportedProfile = supportedProfile or []
        self.documentation = documentation
        self.interaction = interaction or []
        self.versioning = versioning
        self.readHistory = readHistory
        self.updateCreate = updateCreate
        self.conditionalCreate = conditionalCreate
        self.conditionalRead = conditionalRead
        self.conditionalUpdate = conditionalUpdate
        self.conditionalPatch = conditionalPatch
        self.conditionalDelete = conditionalDelete
        self.referencePolicy = referencePolicy or []
        self.searchInclude = searchInclude or []
        self.searchRevInclude = searchRevInclude or []
        self.searchParam = searchParam or []
        self.operation = operation or []

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Interaction(FhirBaseModel):
    """A specification of restful operations supported by the system.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: transaction | batch | search-system | history-system
    :param str documentation: Anything special about operation behavior
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Rest(FhirBaseModel):
    """A definition of the restful capabilities of the solution, if any.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str mode: client | server
    :param str documentation: General description of implementation
    :param Security security: Information about security of implementation
    :param Resource resource: Resource served on the REST interface
    :param Interaction interaction: What operations are supported?
    :param SearchParam searchParam: Search parameters for searching all resources
    :param Operation operation: Definition of a system level operation
    :param str compartment: Compartments served/used by system
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "security": {"class_name": "Security", "is_contained": True},
        "resource": {"class_name": "Resource", "is_contained": True},
        "interaction": {"class_name": "Interaction", "is_contained": True},
        "searchParam": {"class_name": "SearchParam", "is_contained": True},
        "operation": {"class_name": "Operation", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "str" = None,
        documentation: "str" = None,
        security: "Security" = None,
        resource: list["Resource"] = None,
        interaction: list["Interaction"] = None,
        searchParam: list["SearchParam"] = None,
        operation: list["Operation"] = None,
        compartment: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.documentation = documentation
        self.security = security
        self.resource = resource or []
        self.interaction = interaction or []
        self.searchParam = searchParam or []
        self.operation = operation or []
        self.compartment = compartment or []

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Endpoint(FhirBaseModel):
    """An endpoint (network accessible address) to which messages and/or replies are to be sent.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding protocol: http | ftp | mllp +
    :param str address: Network address or identifier of the end-point
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "protocol": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        protocol: "Coding" = None,
        address: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.protocol = protocol
        self.address = address

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SupportedMessage(FhirBaseModel):
    """References to message definitions for messages this system can send or receive.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str mode: sender | receiver
    :param str definition: Message supported by this system
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "str" = None,
        definition: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.definition = definition

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Messaging(FhirBaseModel):
    """A description of the messaging capabilities of the solution.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Endpoint endpoint: Where messages should be sent
    :param int reliableCache: Reliable Message Cache Length (min)
    :param str documentation: Messaging interface behavior details
    :param SupportedMessage supportedMessage: Messages supported by this system
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "endpoint": {"class_name": "Endpoint", "is_contained": True},
        "supportedMessage": {"class_name": "SupportedMessage", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        endpoint: list["Endpoint"] = None,
        reliableCache: "int" = None,
        documentation: "str" = None,
        supportedMessage: list["SupportedMessage"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.endpoint = endpoint or []
        self.reliableCache = reliableCache
        self.documentation = documentation
        self.supportedMessage = supportedMessage or []

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Document(FhirBaseModel):
    """A document definition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str mode: producer | consumer
    :param str documentation: Description of document support
    :param str profile: Constraint on the resources used in the document
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "str" = None,
        documentation: "str" = None,
        profile: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.documentation = documentation
        self.profile = profile

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CapabilityStatement(DomainResource):
    """A Capability Statement documents a set of capabilities (behaviors) of a FHIR Server or Client for a particular version of FHIR that may be used as a statement of actual server functionality or a statement of required or desired server implementation.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this capability statement, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the CapabilityStatement (business identifier)
    :param str version: Business version of the capability statement
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this capability statement (computer friendly)
    :param str title: Name for this capability statement (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the capability statement
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for capability statement (if applicable)
    :param str purpose: Why this capability statement is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str kind: instance | capability | requirements
    :param str instantiates: Canonical URL of another capability statement this implements
    :param str imports: Canonical URL of another capability statement this adds to
    :param Software software: Software that is covered by this capability statement
    :param Implementation implementation: If this describes a specific instance
    :param str fhirVersion: FHIR Version the system supports
    :param str format: formats supported (xml | json | ttl | mime type)
    :param str patchFormat: Patch formats supported
    :param str acceptLanguage: Languages supported
    :param Rest rest: If the endpoint is a RESTful one
    :param Messaging messaging: If messaging is supported
    :param Document document: Document definition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "software": {"class_name": "Software", "is_contained": True},
        "implementation": {"class_name": "Implementation", "is_contained": True},
        "rest": {"class_name": "Rest", "is_contained": True},
        "messaging": {"class_name": "Messaging", "is_contained": True},
        "document": {"class_name": "Document", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        kind: "str" = None,
        instantiates: list["str"] = None,
        imports: list["str"] = None,
        software: "Software" = None,
        implementation: "Implementation" = None,
        fhirVersion: "str" = None,
        format: list["str"] = None,
        patchFormat: list["str"] = None,
        acceptLanguage: list["str"] = None,
        rest: list["Rest"] = None,
        messaging: list["Messaging"] = None,
        document: list["Document"] = None,
    ):

        self.resourceType = "CapabilityStatement"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.kind = kind
        self.instantiates = instantiates or []
        self.imports = imports or []
        self.software = software
        self.implementation = implementation
        self.fhirVersion = fhirVersion
        self.format = format or []
        self.patchFormat = patchFormat or []
        self.acceptLanguage = acceptLanguage or []
        self.rest = rest or []
        self.messaging = messaging or []
        self.document = document or []

    @classmethod
    def from_dict(cls, data: dict) -> "CapabilityStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "CapabilityStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Citation. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Summary(FhirBaseModel):
    """A human-readable display of key concepts to represent the citation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept style: Format for display of the citation summary
    :param str text: The human-readable display of the citation summary
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "style": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        style: "CodeableConcept" = None,
        text: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.style = style
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Classification(FhirBaseModel):
    """The assignment to an organizing scheme.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of classifier (e.g. publication type, keyword)
    :param CodeableConcept classifier: The specific classification value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        classifier: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.classifier = classifier or []

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StatusDate(FhirBaseModel):
    """The state or status of the citation record paired with an effective date or period for that state.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept activity: Classification of the status
    :param bool actual: Either occurred or expected
    :param Period period: When the status started and/or ended
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "activity": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        activity: "CodeableConcept" = None,
        actual: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.activity = activity
        self.actual = actual
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Version(FhirBaseModel):
    """The defined version of the cited artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str value: The version number or other version identifier
    :param Reference baseCitation: Citation for the main version of the cited artifact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "baseCitation": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        value: "str" = None,
        baseCitation: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.value = value
        self.baseCitation = baseCitation

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StatusDate(FhirBaseModel):
    """An effective date or period, historical or future, actual or expected, for a status of the cited artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept activity: Classification of the status
    :param bool actual: Either occurred or expected
    :param Period period: When the status started and/or ended
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "activity": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        activity: "CodeableConcept" = None,
        actual: "bool" = None,
        period: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.activity = activity
        self.actual = actual
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Title(FhirBaseModel):
    """The title details of the article or artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of title
    :param CodeableConcept language: Used to express the specific language
    :param str text: The title of the article or artifact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: list["CodeableConcept"] = None,
        language: "CodeableConcept" = None,
        text: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type or []
        self.language = language
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Abstract(FhirBaseModel):
    """The abstract may be used to convey article-contained abstracts, externally-created abstracts, or other descriptive summaries.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of abstract
    :param CodeableConcept language: Used to express the specific language
    :param str text: Abstract content
    :param str copyright: Copyright notice for the abstract
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        language: "CodeableConcept" = None,
        text: "str" = None,
        copyright: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.language = language
        self.text = text
        self.copyright = copyright

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Part(FhirBaseModel):
    """The component of the article or artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of component
    :param str value: The specification of the component
    :param Reference baseCitation: The citation for the full article or artifact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "baseCitation": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        value: "str" = None,
        baseCitation: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.value = value
        self.baseCitation = baseCitation

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class RelatesTo(FhirBaseModel):
    """The artifact related to the cited artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: documentation | justification | citation | predecessor | successor | derived-from | depends-on | composed-of | part-of | amends | amended-with | appends | appended-with | cites | cited-by | comments-on | comment-in | contains | contained-in | corrects | correction-in | replaces | replaced-with | retracts | retracted-by | signs | similar-to | supports | supported-with | transforms | transformed-into | transformed-with | documents | specification-of | created-with | cite-as | reprint | reprint-of
    :param CodeableConcept classifier: Additional classifiers
    :param str label: Short label
    :param str display: Brief description of the related artifact
    :param str citation: Bibliographic citation for the artifact
    :param Attachment document: What document is being referenced
    :param str resource: What artifact is being referenced
    :param Reference resourceReference: What artifact, if not a conformance resource
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "document": {"class_name": "Attachment", "is_contained": False},
        "resourceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        classifier: list["CodeableConcept"] = None,
        label: "str" = None,
        display: "str" = None,
        citation: "str" = None,
        document: "Attachment" = None,
        resource: "str" = None,
        resourceReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.classifier = classifier or []
        self.label = label
        self.display = display
        self.citation = citation
        self.document = document
        self.resource = resource
        self.resourceReference = resourceReference

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PublishedIn(FhirBaseModel):
    """The collection the cited article or artifact is published in.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Kind of container (e.g. Periodical, database, or book)
    :param Identifier identifier: Journal identifiers include ISSN, ISO Abbreviation and NLMuniqueID; Book identifiers include ISBN
    :param str title: Name of the database or title of the book or journal
    :param Reference publisher: Name of or resource describing the publisher
    :param str publisherLocation: Geographic location of the publisher
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "publisher": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        identifier: list["Identifier"] = None,
        title: "str" = None,
        publisher: "Reference" = None,
        publisherLocation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.identifier = identifier or []
        self.title = title
        self.publisher = publisher
        self.publisherLocation = publisherLocation

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PublicationForm(FhirBaseModel):
    """If multiple, used to represent alternative forms of the article that are not separate citations.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param PublishedIn publishedIn: The collection the cited article or artifact is published in
    :param CodeableConcept citedMedium: Internet or Print
    :param str volume: Volume number of journal or other collection in which the article is published
    :param str issue: Issue, part or supplement of journal or other collection in which the article is published
    :param str articleDate: The date the article was added to the database, or the date the article was released
    :param str publicationDateText: Text representation of the date on which the issue of the cited artifact was published
    :param str publicationDateSeason: Season in which the cited artifact was published
    :param str lastRevisionDate: The date the article was last revised or updated in the database
    :param CodeableConcept language: Language(s) in which this form of the article is published
    :param str accessionNumber: Entry number or identifier for inclusion in a database
    :param str pageString: Used for full display of pagination
    :param str firstPage: Used for isolated representation of first page
    :param str lastPage: Used for isolated representation of last page
    :param str pageCount: Number of pages or screens
    :param str copyright: Copyright notice for the full article or artifact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "publishedIn": {"class_name": "PublishedIn", "is_contained": True},
        "citedMedium": {"class_name": "CodeableConcept", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        publishedIn: "PublishedIn" = None,
        citedMedium: "CodeableConcept" = None,
        volume: "str" = None,
        issue: "str" = None,
        articleDate: "str" = None,
        publicationDateText: "str" = None,
        publicationDateSeason: "str" = None,
        lastRevisionDate: "str" = None,
        language: list["CodeableConcept"] = None,
        accessionNumber: "str" = None,
        pageString: "str" = None,
        firstPage: "str" = None,
        lastPage: "str" = None,
        pageCount: "str" = None,
        copyright: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.publishedIn = publishedIn
        self.citedMedium = citedMedium
        self.volume = volume
        self.issue = issue
        self.articleDate = articleDate
        self.publicationDateText = publicationDateText
        self.publicationDateSeason = publicationDateSeason
        self.lastRevisionDate = lastRevisionDate
        self.language = language or []
        self.accessionNumber = accessionNumber
        self.pageString = pageString
        self.firstPage = firstPage
        self.lastPage = lastPage
        self.pageCount = pageCount
        self.copyright = copyright

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class WebLocation(FhirBaseModel):
    """Used for any URL for the article or artifact cited.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept classifier: Code the reason for different URLs, e.g. abstract and full-text
    :param str url: The specific URL
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        classifier: list["CodeableConcept"] = None,
        url: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.classifier = classifier or []
        self.url = url

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Classification(FhirBaseModel):
    """The assignment to an organizing scheme.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The kind of classifier (e.g. publication type, keyword)
    :param CodeableConcept classifier: The specific classification value
    :param Reference artifactAssessment: Complex or externally created classification
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "artifactAssessment": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        classifier: list["CodeableConcept"] = None,
        artifactAssessment: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.classifier = classifier or []
        self.artifactAssessment = artifactAssessment or []

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ContributionInstance(FhirBaseModel):
    """Contributions with accounting for time or number.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The specific contribution
    :param str time: The time that the contribution was made
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        time: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.time = time

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Entry(FhirBaseModel):
    """An individual entity named as a contributor, for example in the author list or contributor list.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference contributor: The identity of the individual contributor
    :param str forenameInitials: For citation styles that use initials
    :param Reference affiliation: Organizational affiliation
    :param CodeableConcept contributionType: The specific contribution
    :param CodeableConcept role: The role of the contributor (e.g. author, editor, reviewer, funder)
    :param ContributionInstance contributionInstance: Contributions with accounting for time or number
    :param bool correspondingContact: Whether the contributor is the corresponding contributor for the role
    :param int rankingOrder: Ranked order of contribution
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contributor": {"class_name": "Reference", "is_contained": False},
        "affiliation": {"class_name": "Reference", "is_contained": False},
        "contributionType": {"class_name": "CodeableConcept", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "contributionInstance": {
            "class_name": "ContributionInstance",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        contributor: "Reference" = None,
        forenameInitials: "str" = None,
        affiliation: list["Reference"] = None,
        contributionType: list["CodeableConcept"] = None,
        role: "CodeableConcept" = None,
        contributionInstance: list["ContributionInstance"] = None,
        correspondingContact: "bool" = None,
        rankingOrder: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.contributor = contributor
        self.forenameInitials = forenameInitials
        self.affiliation = affiliation or []
        self.contributionType = contributionType or []
        self.role = role
        self.contributionInstance = contributionInstance or []
        self.correspondingContact = correspondingContact
        self.rankingOrder = rankingOrder

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Summary(FhirBaseModel):
    """Used to record a display of the author/contributor list without separate data element for each list member.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Such as author list, contributorship statement, funding statement, acknowledgements statement, or conflicts of interest statement
    :param CodeableConcept style: The format for the display string
    :param CodeableConcept source: Used to code the producer or rule for creating the display string
    :param str value: The display string for the author list, contributor list, or contributorship statement
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "style": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        style: "CodeableConcept" = None,
        source: "CodeableConcept" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.style = style
        self.source = source
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Contributorship(FhirBaseModel):
    """This element is used to list authors and other contributors, their contact information, specific contributions, and summary statements.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool complete: Indicates if the list includes all authors and/or contributors
    :param Entry entry: An individual entity named as a contributor
    :param Summary summary: Used to record a display of the author/contributor list without separate data element for each list member
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "entry": {"class_name": "Entry", "is_contained": True},
        "summary": {"class_name": "Summary", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        complete: "bool" = None,
        entry: list["Entry"] = None,
        summary: list["Summary"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.complete = complete
        self.entry = entry or []
        self.summary = summary or []

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CitedArtifact(FhirBaseModel):
    """The article or artifact being described.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Unique identifier. May include DOI, PMID, PMCID, etc
    :param Identifier relatedIdentifier: Identifier not unique to the cited artifact. May include trial registry identifiers
    :param str dateAccessed: When the cited artifact was accessed
    :param Version version: The defined version of the cited artifact
    :param CodeableConcept currentState: The status of the cited artifact
    :param StatusDate statusDate: An effective date or period for a status of the cited artifact
    :param Title title: The title details of the article or artifact
    :param Abstract abstract: Summary of the article or artifact
    :param Part part: The component of the article or artifact
    :param RelatesTo relatesTo: The artifact related to the cited artifact
    :param PublicationForm publicationForm: If multiple, used to represent alternative forms of the article that are not separate citations
    :param WebLocation webLocation: Used for any URL for the article or artifact cited
    :param Classification classification: The assignment to an organizing scheme
    :param Contributorship contributorship: Attribution of authors and other contributors
    :param Annotation note: Any additional information or content for the article or artifact
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "relatedIdentifier": {"class_name": "Identifier", "is_contained": False},
        "version": {"class_name": "Version", "is_contained": True},
        "currentState": {"class_name": "CodeableConcept", "is_contained": False},
        "statusDate": {"class_name": "StatusDate", "is_contained": True},
        "title": {"class_name": "Title", "is_contained": True},
        "abstract": {"class_name": "Abstract", "is_contained": True},
        "part": {"class_name": "Part", "is_contained": True},
        "relatesTo": {"class_name": "RelatesTo", "is_contained": True},
        "publicationForm": {"class_name": "PublicationForm", "is_contained": True},
        "webLocation": {"class_name": "WebLocation", "is_contained": True},
        "classification": {"class_name": "Classification", "is_contained": True},
        "contributorship": {"class_name": "Contributorship", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        relatedIdentifier: list["Identifier"] = None,
        dateAccessed: "str" = None,
        version: "Version" = None,
        currentState: list["CodeableConcept"] = None,
        statusDate: list["StatusDate"] = None,
        title: list["Title"] = None,
        abstract: list["Abstract"] = None,
        part: "Part" = None,
        relatesTo: list["RelatesTo"] = None,
        publicationForm: list["PublicationForm"] = None,
        webLocation: list["WebLocation"] = None,
        classification: list["Classification"] = None,
        contributorship: "Contributorship" = None,
        note: list["Annotation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.relatedIdentifier = relatedIdentifier or []
        self.dateAccessed = dateAccessed
        self.version = version
        self.currentState = currentState or []
        self.statusDate = statusDate or []
        self.title = title or []
        self.abstract = abstract or []
        self.part = part
        self.relatesTo = relatesTo or []
        self.publicationForm = publicationForm or []
        self.webLocation = webLocation or []
        self.classification = classification or []
        self.contributorship = contributorship
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Citation(DomainResource):
    """The Citation Resource enables reference to any knowledge artifact for purposes of identification and attribution. The Citation Resource supports existing reference structures and developing publication practices such as versioning, expressing complex contributorship roles, and referencing computable resources.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this citation record, represented as a globally unique URI
    :param Identifier identifier: Identifier for the citation record itself
    :param str version: Business version of the citation record
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this citation record (computer friendly)
    :param str title: Name for this citation record (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: The publisher of the citation record, not the publisher of the article or artifact being cited
    :param ContactDetail contact: Contact details for the publisher of the citation record
    :param str description: Natural language description of the citation
    :param UsageContext useContext: The context that the citation record content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for citation record (if applicable)
    :param str purpose: Why this citation is defined
    :param str copyright: Use and/or publishing restrictions for the citation record, not for the cited artifact
    :param str copyrightLabel: Copyright holder and year(s) for the ciation record, not for the cited artifact
    :param str approvalDate: When the citation record was approved by publisher
    :param str lastReviewDate: When the citation record was last reviewed by the publisher
    :param Period effectivePeriod: When the citation record is expected to be used
    :param ContactDetail author: Who authored the citation record
    :param ContactDetail editor: Who edited the citation record
    :param ContactDetail reviewer: Who reviewed the citation record
    :param ContactDetail endorser: Who endorsed the citation record
    :param Summary summary: A human-readable display of key concepts to represent the citation
    :param Classification classification: The assignment to an organizing scheme
    :param Annotation note: Used for general notes and annotations not coded elsewhere
    :param CodeableConcept currentState: The status of the citation record
    :param StatusDate statusDate: An effective date or period for a status of the citation record
    :param RelatedArtifact relatedArtifact: Artifact related to the citation record
    :param CitedArtifact citedArtifact: The article or artifact being described
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "summary": {"class_name": "Summary", "is_contained": True},
        "classification": {"class_name": "Classification", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
        "currentState": {"class_name": "CodeableConcept", "is_contained": False},
        "statusDate": {"class_name": "StatusDate", "is_contained": True},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "citedArtifact": {"class_name": "CitedArtifact", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        summary: list["Summary"] = None,
        classification: list["Classification"] = None,
        note: list["Annotation"] = None,
        currentState: list["CodeableConcept"] = None,
        statusDate: list["StatusDate"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        citedArtifact: "CitedArtifact" = None,
    ):

        self.resourceType = "Citation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.summary = summary or []
        self.classification = classification or []
        self.note = note or []
        self.currentState = currentState or []
        self.statusDate = statusDate or []
        self.relatedArtifact = relatedArtifact or []
        self.citedArtifact = citedArtifact

    @classmethod
    def from_dict(cls, data: dict) -> "Citation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Citation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
